@@ -12,6 +12,7 @@ from .enhance_config import main as enhance_config_main
 from .initialize import main as initialize_main
 from .verify_database import main as verify_database_main
 from .resource_pack.main import main as resource_pack_main
+from .datapack.recipes import main as recipes_main
 from .manual.main import main as manual_main
 from .datapack.main import main as datapack_main
 from .compatibilities.main import main as compatibilities_main
@@ -56,6 +57,7 @@ def check_config_format(config: dict) -> bool:
 	has_manual = basic_key_check(config, "has_manual", bool, "Do the program generate a manual/guide? (WARNING: if an item is malformed in the database, the server log will be flooded on load by the manual hiding the malformed item)", True)
 	if has_manual == True:
 		valid = basic_key_check(config, "manual_path", str, "Cached manual assets", valid)
+		valid = basic_key_check(config, "manual_overrides", str, "Path to a folder containing manual overrides to replace the default manual assets", valid)
 		valid = basic_key_check(config, "manual_high_resolution", bool, "Enable the high resolution for the manual to increase the craft resolutions", valid)
 		valid = basic_key_check(config, "cache_manual_assets", bool, "Caches the MC assets and the items renders for the manual (manual/items/*.png)", valid)
 		valid = basic_key_check(config, "cache_manual_pages", bool, "Caches the content of the manual and the images (manual/pages/*.png)", valid)
@@ -108,6 +110,10 @@ def build_process(config: dict, setup_database: callable = None, setup_external_
 		if config.get("resource_pack_format"):
 			resource_pack_main(config)
 
+		# Generate custom recipes if any
+		if config.get("database"):
+			recipes_main(config)
+
 		# Generate manual
 		if config.get("has_manual") == True:
 			manual_main(config)
