@@ -231,6 +231,7 @@ def generate_everything_about_this_material(config: dict, database: dict[str, di
 				if f"{pulv_ingr}.png" in config['textures_files']:
 					database[item][RESULT_OF_CRAFTING].append({"type":PULVERIZING,"result_count":2,"category":"misc","group":material_base,"ingredient":ingr_repr(pulv_ingr, config['namespace'])})
 		if item.endswith("nugget"):
+			database[item][RESULT_OF_CRAFTING].insert(0, {"type":"crafting_shapeless","result_count":9,"category":"misc","group":material_base,"ingredients":[main_ingredient]})
 			for gear in SLOTS.keys():
 				if f"{material_base}_{gear}.png" in config['textures_files']:
 					database[item][RESULT_OF_CRAFTING].append({"type":"smelting","result_count":1,"category":"equipment","experience":0.8,"cookingtime":200,"ingredient":ingr_repr(f"{material_base}_{gear}", config['namespace'])})
@@ -389,7 +390,7 @@ def clean_record_name(name: str) -> str:
 	return "".join([c for c in name if c in A_Z + ZERO_NINE + UNDERSCORE])
 			
 # Custom records
-def generate_custom_records(config: dict, database: dict[str, dict], records: dict[str, str]|str|None, category: str|None = None) -> None:
+def generate_custom_records(config: dict, database: dict[str, dict], records: dict[str, str]|str|None = "auto", category: str|None = None) -> None:
 	""" Generate custom records by searching in config['assets_folder']/records/ for the files and copying them to the database and resource pack folder.
 	Args:
 		database	(dict[str, dict]):	The database to add the custom records items to, ex: {"record_1": "song.ogg", "record_2": "another_song.ogg"}
